@@ -170,6 +170,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import cdk8s
@@ -188,11 +190,11 @@ class Jenkins(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        base_plugins: typing.Optional[typing.Sequence["Plugin"]] = None,
+        base_plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
         disable_csrf_protection: typing.Optional[builtins.bool] = None,
-        metadata: typing.Optional[cdk8s.ApiObjectMetadata] = None,
-        plugins: typing.Optional[typing.Sequence["Plugin"]] = None,
-        seed_jobs: typing.Optional[typing.Sequence["SeedJob"]] = None,
+        metadata: typing.Optional[typing.Union[cdk8s.ApiObjectMetadata, typing.Dict[str, typing.Any]]] = None,
+        plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
+        seed_jobs: typing.Optional[typing.Sequence[typing.Union["SeedJob", typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -203,6 +205,10 @@ class Jenkins(
         :param plugins: List of custom plugins applied to Jenkins resource. Default: - []
         :param seed_jobs: List of seed job configuration for Jenkins resource. For more information about seed jobs, please take a look at { @link https://github.com/jenkinsci/job-dsl-plugin/wiki/Tutorial---Using-the-Jenkins-Job-DSL Jenkins Seed Jobs Documentation }. Default: - No seed jobs
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Jenkins.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = JenkinsProps(
             base_plugins=base_plugins,
             disable_csrf_protection=disable_csrf_protection,
@@ -219,6 +225,9 @@ class Jenkins(
 
         :param base_plugins: List of base plugins.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Jenkins.add_base_plugins)
+            check_type(argname="argument base_plugins", value=base_plugins, expected_type=typing.Tuple[type_hints["base_plugins"], ...])
         return typing.cast(None, jsii.invoke(self, "addBasePlugins", [*base_plugins]))
 
     @jsii.member(jsii_name="addPlugins")
@@ -227,6 +236,9 @@ class Jenkins(
 
         :param plugins: List of custom plugins.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Jenkins.add_plugins)
+            check_type(argname="argument plugins", value=plugins, expected_type=typing.Tuple[type_hints["plugins"], ...])
         return typing.cast(None, jsii.invoke(self, "addPlugins", [*plugins]))
 
     @jsii.member(jsii_name="addSeedJobs")
@@ -235,6 +247,9 @@ class Jenkins(
 
         :param seed_jobs: List of seed jobs.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Jenkins.add_seed_jobs)
+            check_type(argname="argument seed_jobs", value=seed_jobs, expected_type=typing.Tuple[type_hints["seed_jobs"], ...])
         return typing.cast(None, jsii.invoke(self, "addSeedJobs", [*seed_jobs]))
 
 
@@ -253,11 +268,11 @@ class JenkinsProps:
     def __init__(
         self,
         *,
-        base_plugins: typing.Optional[typing.Sequence["Plugin"]] = None,
+        base_plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
         disable_csrf_protection: typing.Optional[builtins.bool] = None,
-        metadata: typing.Optional[cdk8s.ApiObjectMetadata] = None,
-        plugins: typing.Optional[typing.Sequence["Plugin"]] = None,
-        seed_jobs: typing.Optional[typing.Sequence["SeedJob"]] = None,
+        metadata: typing.Optional[typing.Union[cdk8s.ApiObjectMetadata, typing.Dict[str, typing.Any]]] = None,
+        plugins: typing.Optional[typing.Sequence[typing.Union["Plugin", typing.Dict[str, typing.Any]]]] = None,
+        seed_jobs: typing.Optional[typing.Sequence[typing.Union["SeedJob", typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''Props for ``Jenkins``.
 
@@ -269,6 +284,13 @@ class JenkinsProps:
         '''
         if isinstance(metadata, dict):
             metadata = cdk8s.ApiObjectMetadata(**metadata)
+        if __debug__:
+            type_hints = typing.get_type_hints(JenkinsProps.__init__)
+            check_type(argname="argument base_plugins", value=base_plugins, expected_type=type_hints["base_plugins"])
+            check_type(argname="argument disable_csrf_protection", value=disable_csrf_protection, expected_type=type_hints["disable_csrf_protection"])
+            check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
+            check_type(argname="argument plugins", value=plugins, expected_type=type_hints["plugins"])
+            check_type(argname="argument seed_jobs", value=seed_jobs, expected_type=type_hints["seed_jobs"])
         self._values: typing.Dict[str, typing.Any] = {}
         if base_plugins is not None:
             self._values["base_plugins"] = base_plugins
@@ -379,6 +401,11 @@ class Plugin:
         :param version: The version of Jenkins plugin.
         :param download_url: The url from where plugin has to be downloaded. Default: - Plugins are downloaded from Jenkins Update Centers.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Plugin.__init__)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
+            check_type(argname="argument download_url", value=download_url, expected_type=type_hints["download_url"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "version": version,
@@ -452,6 +479,13 @@ class SeedJob:
         :param repository_url: The repository access URL. Supports SSH and HTTPS.
         :param targets: The repository path where seed job definitions are present.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SeedJob.__init__)
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument repository_branch", value=repository_branch, expected_type=type_hints["repository_branch"])
+            check_type(argname="argument repository_url", value=repository_url, expected_type=type_hints["repository_url"])
+            check_type(argname="argument targets", value=targets, expected_type=type_hints["targets"])
         self._values: typing.Dict[str, typing.Any] = {
             "description": description,
             "id": id,
